summaryrefslogtreecommitdiffstats
path: root/Modules/FindQt.cmake
diff options
context:
space:
mode:
authorFranck Bettinger <bettingf@cs.man.ac.uk>2001-11-09 17:08:50 (GMT)
committerFranck Bettinger <bettingf@cs.man.ac.uk>2001-11-09 17:08:50 (GMT)
commit123f9b50eaf9b31b56144454658b0f629dda2cbb (patch)
tree98128cb9398d4b0ed8700780951f54a595b15732 /Modules/FindQt.cmake
parent53d0de2a9f0359396b48e398f79030a733fcb5de (diff)
downloadCMake-123f9b50eaf9b31b56144454658b0f629dda2cbb.zip
CMake-123f9b50eaf9b31b56144454658b0f629dda2cbb.tar.gz
CMake-123f9b50eaf9b31b56144454658b0f629dda2cbb.tar.bz2
support for compilation of .ui files into .h and .cxx files
Diffstat (limited to 'Modules/FindQt.cmake')
-rw-r--r--Modules/FindQt.cmake18
1 files changed, 17 insertions, 1 deletions
diff --git a/Modules/FindQt.cmake b/Modules/FindQt.cmake
index f3de113..9229108 100644
--- a/Modules/FindQt.cmake
+++ b/Modules/FindQt.cmake
@@ -3,9 +3,11 @@
# This module defines
# QT_INCLUDE_PATH, where to find qt.h, etc.
# QT_QT_LIBRARY, where to find the qt library
# QT_MOX_EXE, where to find the moc tool
# USE_QT_FILE, a file for any CMakeLists.txt file to include to actually link against qt
# QT_WRAP_CPP, This allows the QT_WRAP_CPP command to work.
+# QT_WRAP_UI, This allows the QT_WRAP_UI command to work.
IF (UNIX)
@@ -29,6 +31,11 @@ IF (UNIX)
${path}
)
+ FIND_FILE(QT_UIC_EXE uic
+ ${QTDIR}/bin
+ ${path}
+ )
+
ENDIF (UNIX)
IF (WIN32)
@@ -48,6 +55,11 @@ IF (WIN32)
${path}
)
+ FIND_FILE(QT_MOC_EXE uic.exe
+ ${QTDIR}/bin
+ ${path}
+ )
+
ENDIF (WIN32)
@@ -55,6 +67,10 @@ IF (QT_MOC_EXE)
SET ( QT_WRAP_CPP 1 CACHE BOOL "Can we honour the QT_WRAP_CPP command" )
ENDIF (QT_MOC_EXE)
+IF (QT_UIC_EXE)
+ SET ( QT_WRAP_UI 1 CACHE BOOL "Can we honour the QT_WRAP_UI command" )
+ENDIF (QT_UIC_EXE)
+
@@ -3,9 +3,11 @@
# QT_INCLUDE_PATH, where to find qt.h, etc.
# QT_QT_LIBRARY, where to find the qt library
-# QT_MOX_EXE, where to find the moc tool
+# QT_MOC_EXE, where to find the moc tool
+# QT_UIC_EXE, where to find the uic tool
# USE_QT_FILE, a file for any CMakeLists.txt file to include to actually link against qt
# QT_WRAP_CPP, This allows the QT_WRAP_CPP command to work.